bread.views package
===================

.. automodule:: bread.views
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

bread.views.add module
----------------------

.. automodule:: bread.views.add
   :members:
   :undoc-members:
   :show-inheritance:

bread.views.auth module
-----------------------

.. automodule:: bread.views.auth
   :members:
   :undoc-members:
   :show-inheritance:

bread.views.browse module
-------------------------

.. automodule:: bread.views.browse
   :members:
   :undoc-members:
   :show-inheritance:

bread.views.delete module
-------------------------

.. automodule:: bread.views.delete
   :members:
   :undoc-members:
   :show-inheritance:

bread.views.edit module
-----------------------

.. automodule:: bread.views.edit
   :members:
   :undoc-members:
   :show-inheritance:

bread.views.read module
-----------------------

.. automodule:: bread.views.read
   :members:
   :undoc-members:
   :show-inheritance:

bread.views.system module
-------------------------

.. automodule:: bread.views.system
   :members:
   :undoc-members:
   :show-inheritance:

bread.views.util module
-----------------------

.. automodule:: bread.views.util
   :members:
   :undoc-members:
   :show-inheritance:

bread.views.wizard module
-------------------------

.. automodule:: bread.views.wizard
   :members:
   :undoc-members:
   :show-inheritance:
